#!/bin/bash -l

# This script is executed on the machine at which autosubmit is executed.

# Because it can happen that the initial conditions as well and the execution happens in the local
# system we need to define these two variables:
DATA_IS_LOCAL=%SIMULATION.INITIAL_CONDITIONS.LOCAL%

if [ "x%HPCARCH%" == "xlocal" ]; then
  RUN_MACHINE_IS_LOCAL="True"
else
  RUN_MACHINE_IS_LOCAL="False"
fi

# Get some variables provided by autosubmit.
WORKDIR=%HPCROOTDIR%
STARTDATE=%SDATE%
HPCUSER=%HPCUSER%
HPCHOST=%HPCHOST%

# Define date directory, create it and go there
COMMON_DATE_FOLDER=${WORKDIR}/${STARTDATE}/inidata

AN_MEMBER=$(printf "%03d" %SIMULATION.INITIAL_CONDITIONS.MEMBER%)
INITIAL_CONDITIONS_PARENT_FOLDER=%SIMULATION.INITIAL_CONDITIONS.PARENT_FOLDER%
INITIAL_CONDITIONS_PATH=${INITIAL_CONDITIONS_PARENT_FOLDER}/${STARTDATE:0:6}/${STARTDATE:0:8}T00

AN_FILES=$(find ${INITIAL_CONDITIONS_PATH} -name "igaf*.m*.grb" | sort -n )
FG_FILES=$(find ${INITIAL_CONDITIONS_PATH} -name "igfff00030000.m*.grb" | sort -n )

# Find files
if [ -z "${AN_FILES}" ]; then
  echo "Analysis files for date ${STARTDATE} not found!"
  exit 1
fi

if [ -z "${FG_FILES}" ]; then
  echo "FG files for date ${STARTDATE} not found!"
  exit 1
fi


# Check if we copy the initial conditions from the local system or the remote one
if [ "${RUN_MACHINE_IS_LOCAL}" != "True" ]; then
  # Create member folder
  ssh "${HPCUSER}@${HPCHOST}" mkdir -p ${COMMON_DATE_FOLDER}

  # Transfer analysis and first-guess files
  rsync -v ${AN_FILES} "${HPCUSER}@${HPCHOST}":"${COMMON_DATE_FOLDER}/"
  rsync -v ${FG_FILES} "${HPCUSER}@${HPCHOST}":"${COMMON_DATE_FOLDER}/"

  # Change permissions to read only.
  ssh "${HPCUSER}@${HPCHOST}" chmod 440 "${COMMON_DATE_FOLDER}/*"
else
  # Create member folder and go there
  mkdir -p ${COMMON_DATE_FOLDER}
  cd ${COMMON_DATE_FOLDER} || exit



  # Copy the first-guess and analysis files.
  # Transfer analysis and first-guess files
  rsync -v ${AN_FILES} "${COMMON_DATE_FOLDER}/"
  rsync -v ${FG_FILES} "${COMMON_DATE_FOLDER}/"

  # Change permissions to read only.
  chmod 440 ./*
fi