#!/bin/bash -l

# Get some variables provided by autosubmit.
WORKDIR=%HPCROOTDIR%
DYNAMICS_GRID_FILENAME=%simulation.dynamics_grid_filename%
RADIATION_GRID_FILE=%simulation.radiation_grid_filename%
EXTERNAL_PARAMETERS_FILE=%simulation.external_parameters_filename%
SST_FORCING=%simulation.initial_conditions.sea_surface_temperature_forcing%

# Activate spack
. ${WORKDIR}/production_project/platforms/common/spack_utils.sh
load_spack "%spack.init%" "%spack.root%" "%spack.url%" "%spack.branch%" "%spack.externals%" "%spack.compiler%" "%spack.disable_local_config%" "%spack.user_cache_path%" "%spack.user_config_path%" "%spack.upstreams%"

# Load icon module needed to retrieve some data
spack load --first icon-nwp@%ICON_VERSION%

# Create a folder for the common inidata and go there
COMMON_INIDATA_FOLDER=${WORKDIR}/inidata
mkdir -p "${COMMON_INIDATA_FOLDER}"
cd "${COMMON_INIDATA_FOLDER}" || exit

# Change permissions
chmod 660 ./*

# Download or copy required input files
function download_file() {
  URL=$1
  FILE=${2:-$(basename "$URL")}
  if [ ! -e "$FILE" ]; then
    echo "Download $URL => $FILE"
    wget -q "$URL" -O "$FILE"
  fi
}

function check_url() {
  # Check if the url exists
  local url="$1"
  status=$(
    (curl -s --head $url | head -n 1 | grep  "HTTP/1.[01] [23].." >/dev/null)
    echo $?
  )
  if [ $status -eq 0 ]; then
    echo "true"
  else
    echo "false"
  fi
}

function get_grfinfo_file(){
  local filename="$1"
  new_suffix="-grfinfo.nc"
  new_filename="$(basename "$filename" .nc)$new_suffix"
  echo "$new_filename"
}

# Download grid files and external parameters
BASEURL=http://icon-downloads.mpimet.mpg.de/grids/public/edzw
download_file $BASEURL/${DYNAMICS_GRID_FILENAME}
download_file $BASEURL/${RADIATION_GRID_FILE}
download_file $BASEURL/${EXTERNAL_PARAMETERS_FILE}

# In case the grfinfo files exist, we download them as well
RADIATION_GRID_INFO_FILE=$( get_grfinfo_file ${RADIATION_GRID_FILE} )
DYNAMICS_GRID_INFO_FILE=$( get_grfinfo_file ${DYNAMICS_GRID_FILENAME} )

if [ $( check_url "$BASEURL/${RADIATION_GRID_INFO_FILE}" ) == "true" ]; then
  download_file "$BASEURL/${RADIATION_GRID_INFO_FILE}"
fi

if [ $( check_url "$BASEURL/${DYNAMICS_GRID_INFO_FILE}" ) == "true" ]; then
  download_file "$BASEURL/${DYNAMICS_GRID_INFO_FILE}"
fi


# Define the function
function grid_filename_from_extpar() {
    local filename="$1"
    # Extract the grid identifier from the filename
    grid_id="${filename:12:13}"
    grid_filename="icon_grid_${grid_id}.nc"
    echo "${grid_filename}"
}

# If the externap parameters file is in a different grid, also download this one.
EXTERNAL_PARAMETERS_GRID_FILE=$( grid_filename_from_extpar ${EXTERNAL_PARAMETERS_FILE} )
if [ "${EXTERNAL_PARAMETERS_GRID_FILE}" != "${DYNAMICS_GRID_FILENAME}" ]; then
  download_file "$BASEURL/${EXTERNAL_PARAMETERS_GRID_FILE}"
fi


# Link input for radiation
ln -sf "${ICON_DATA_PATH}/rrtmg_lw.nc" .
ln -sf "${ICON_DATA_PATH}/ECHAM6_CldOptProps.nc" .
ln -sf "${ICON_BASE_PATH}/run/ana_varnames_map_file.txt" .

# Copy sst forcing
cp "${SST_FORCING}" .

# Change permissions to read only.
chmod 440 ./*